@@ -74,11 +74,9 @@ def read_bed(f, as_df=False, nrows=None):
 
     if f.endswith(".gz"):
         import gzip
-        with gzip.open(f) as handle:
-            first_start = handle.readline().split()[1]
+        first_start = gzip.open(f).readline().split()[1]
     else:
-        with open(f) as handle:
-            first_start = handle.readline().split()[1]
+        first_start = open(f).readline().split()[1]
 
     header = None
 
@@ -256,6 +254,10 @@ def read_gtf(f, full=True, as_df=False, nrows=None, duplicate_attr=False):
 
         Path to GTF file.
 
+    full : bool, default True
+
+        Whether to read and interpret the annotation column.
+
     as_df : bool, default False
 
         Whether to return as pandas DataFrame instead of PyRanges.
@@ -300,7 +302,10 @@ def read_gtf(f, full=True, as_df=False, nrows=None, duplicate_attr=False):
 
     _skiprows = skiprows(f)
 
-    gr = read_gtf_full(f, as_df, nrows, _skiprows, duplicate_attr)
+    if full:
+        gr = read_gtf_full(f, as_df, nrows, _skiprows, duplicate_attr)
+    else:
+        gr = read_gtf_restricted(f, _skiprows, as_df=False, nrows=None)
 
     return gr
 
@@ -359,10 +364,6 @@ def to_rows(anno):
                                       # l[:-1] removes final ";" cheaply
                                       for kv in l[:-1].split("; ")]})
 
-    # for l in anno:
-    #     l = l.replace('"', '').replace(";", "").split()
-    #     rowdicts.append({k: v for k, v in zip(*([iter(l)] * 2))})
-
     return pd.DataFrame.from_dict(rowdicts).set_index(anno.index)
 
 
@@ -390,8 +391,8 @@ def to_rows_keep_duplicates(anno):
 
 
 def read_gtf_restricted(f,
+                        skiprows,
                         as_df=False,
-                        skiprows=0,
                         nrows=None):
     """seqname - name of the chromosome or scaffold; chromosome names can be given with or without the 'chr' prefix. Important note: the seqname must be one used within Ensembl, i.e. a standard chromosome name or an Ensembl identifier such as a scaffold ID, without any additional content such as species or assembly. See the example GFF output below.
     # source - name of the program that generated this feature, or the data source (database or project name)
@@ -417,6 +418,7 @@ def read_gtf_restricted(f,
         names="Chromosome Feature Start End Score Strand Attribute".split(),
         dtype=dtypes,
         chunksize=int(1e5),
+        skiprows=skiprows,
         nrows=nrows)
 
     dfs = []
@@ -459,7 +461,7 @@ def to_rows_gff3(anno):
     return pd.DataFrame.from_dict(rowdicts).set_index(anno.index)
 
 
-def read_gff3(f, annotation=None, as_df=False, nrows=None, skiprows=0):
+def read_gff3(f, full=True, annotation=None, as_df=False, nrows=None):
 
     """Read files in the General Feature Format.
 
@@ -469,6 +471,10 @@ def read_gff3(f, annotation=None, as_df=False, nrows=None, skiprows=0):
 
         Path to GFF file.
 
+    full : bool, default True
+
+        Whether to read and interpret the annotation column.
+
     as_df : bool, default False
 
         Whether to return as pandas DataFrame instead of PyRanges.
@@ -483,6 +489,10 @@ def read_gff3(f, annotation=None, as_df=False, nrows=None, skiprows=0):
     pyranges.read_gtf : read files in the Gene Transfer Format
     """
 
+    _skiprows = skiprows(f)
+
+    if not full:
+        return read_gtf_restricted(f, _skiprows, as_df=as_df, nrows=nrows)
 
     dtypes = {
         "Chromosome": "category",
@@ -501,7 +511,7 @@ def read_gff3(f, annotation=None, as_df=False, nrows=None, skiprows=0):
         names=names,
         dtype=dtypes,
         chunksize=int(1e5),
-        skiprows=skiprows,
+        skiprows=_skiprows,
         nrows=nrows)
 
     dfs = []
